diff src/network.h @ 8834:beb7be215db3

[gaim-migrate @ 9598] I removed account->ip because it isn't used anywhere and I think it's dumb. Also added handling for a and aaaa records to rendezvous. Gaim peeps show up in iChat rendezvous lists now. There are still problems. committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Wed, 28 Apr 2004 00:48:21 +0000
parents b248c1f4efbd
children 518455386538
line wrap: on
line diff
--- a/src/network.h	Tue Apr 27 23:17:12 2004 +0000
+++ b/src/network.h	Wed Apr 28 00:48:21 2004 +0000
@@ -30,26 +30,29 @@
 #endif
 
 /**************************************************************************/
-/** @name Network API                                     */
+/** @name Network API                                                     */
 /**************************************************************************/
 /*@{*/
 
 /**
- * Sets the IP address of the local system in preferences.
+ * Sets the IP address of the local system in preferences.  This
+ * is the IP address that should be used for incoming connections
+ * (file transfer, direct IM, etc.) and should therefore be
+ * publicly accessible.
  *
  * @param ip The local IP address.
  */
-void gaim_network_set_local_ip(const char *ip);
+void gaim_network_set_public_ip(const char *ip);
 
 /**
  * Returns the IP address of the local system set in preferences.
  *
  * This returns the value set via gaim_network_set_local_ip().
  * You probably want to use gaim_network_get_ip_for_account() instead.
  *
  * @return The local IP address set in preferences.
  */
-const char *gaim_network_get_local_ip(void);
+const char *gaim_network_get_public_ip(void);
 
 /**
  * Returns the IP address of the local system.
@@ -66,15 +69,14 @@
 const char *gaim_network_get_local_system_ip(int fd);
 
 /**
- * Returns the IP address that should be used for the specified account.
- *
- * First, if @a account is not @c NULL, the IP associated with @a account
- * is tried, via a call to gaim_account_get_local_ip().
+ * Returns the IP address that should be used anywhere a
+ * public IP addresses is needed (listening for an incoming
+ * file transfer, etc).
  *
- * If that IP is not set, the IP set in preferences is tried.
- *
- * If that IP is not set, the system's local IP is tried, via a call to
- * gaim_network_get_local_ip().
+ * If the user has manually specified an IP address via
+ * preferences, then this IP is returned.  Otherwise the
+ * IP address returned by gaim_network_get_local_system_ip()
+ * is returned.
  *
  * @note The returned string is a pointer to a static buffer. If this
  *       function is called twice, it may be important to make a copy
@@ -140,7 +142,7 @@
  *           possible bug will inspire new and valuable contributors to Gaim.
  * @return The port number, in host byte order.
  */
-short gaim_network_get_port_from_fd(int fd);
+unsigned short gaim_network_get_port_from_fd(int fd);
 
 /**
  * Initializes the network subsystem.
@@ -30,26 +30,29 @@
  * Returns the IP address of the local system set in preferences.
  *
- * This returns the value set via gaim_network_set_local_ip().
+ * This returns the value set via gaim_network_set_public_ip().
  * You probably want to use gaim_network_get_ip_for_account() instead.
  *